=========================================================
PegasusIO for reading / writing single-cell genomics data
=========================================================

|PyPI| |PyPIDownload| |Docs| |Build|

.. |PyPI| image:: https://img.shields.io/pypi/v/pegasusio.svg
   :target: https://pypi.org/project/pegasusio
.. |PyPIDownload| image:: https://pepy.tech/badge/pegasusio
   :target: https://pepy.tech/project/pegasusio
.. |Docs| image:: https://readthedocs.org/projects/pegasusio/badge/?version=latest
   :target: https://pegasusio.readthedocs.io
.. |Build| image:: https://travis-ci.org/klarman-cell-observatory/pegasusio.svg?branch=master
   :target: https://travis-ci.org/github/klarman-cell-observatory/pegasusio

PegasusIO is the IO package for Pegasus.

`Read documentation <http://pegasusio.readthedocs.io>`__
